==> jc-1.4.0.tar.gz: scm/Procedure.h <==
// class scm.Procedure

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Procedure_H_
#define _JC_scm_Procedure_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Procedure$sub_refs	_jc_scm_Procedure$sub_refs;
typedef struct _jc_scm_Procedure$sub_nonrefs	_jc_scm_Procedure$sub_nonrefs;
typedef struct _jc_scm_Procedure$refs	_jc_scm_Procedure$refs;
typedef struct _jc_scm_Procedure$nonrefs	_jc_scm_Procedure$nonrefs;
typedef struct _jc_scm_Procedure$object	_jc_scm_Procedure$object;

typedef const struct _jc_scm_Procedure$vmethods	_jc_scm_Procedure$vmethods;
typedef const struct _jc_scm_Procedure$vtable	_jc_scm_Procedure$vtable;
typedef const struct _jc_scm_Procedure$vtype	_jc_scm_Procedure$vtype;

// Constructors
extern void _jc_scm_Procedure$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Procedure$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_Procedure$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_object *_jc_scm_Procedure$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Env$object *);
extern struct _jc_scm_Env$object *_jc_scm_Procedure$method$extendargs$da3942a08c440de1(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_Procedure$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Procedure$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_Procedure$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Procedure$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Procedure$method_info$extendargs$da3942a08c440de1;
extern _jc_method _jc_scm_Procedure$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Procedure$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Env$object *);
	struct _jc_scm_Env$object	*(*extendargs$da3942a08c440de1)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Procedure$object *);
};

// Vtable
struct _jc_scm_Procedure$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
};

// Vtype
struct _jc_scm_Procedure$vtype {
	_jc_type			type;
	_jc_scm_Procedure$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Procedure$sub_refs {
	struct _jc_scm_Cell$object	*body;
	struct _jc_scm_Cell$object	*formals;
	struct _jc_scm_Env$object	*procenv;
};

// Reference instance fields (object)
struct _jc_scm_Procedure$refs {
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Procedure$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Procedure$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
};

// Object instance structure
struct _jc_scm_Procedure$object {
	_jc_scm_Procedure$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Procedure$vtype	*vtype;
	_jc_scm_Procedure$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Procedure$vtype _jc_scm_Procedure$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Procedure, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Procedure$class_object;

#endif	/* _JC_scm_Procedure_H_ */

==> jc-1.4.6.tar.gz: scm/Procedure.h <==
// class scm.Procedure

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 6d0a82a28dffac88 scm_Procedure

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_Procedure_H_
#define _JC_scm_Procedure_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Cell$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_Procedure$sub_refs	_jc_scm_Procedure$sub_refs;
typedef struct _jc_scm_Procedure$sub_nonrefs	_jc_scm_Procedure$sub_nonrefs;
typedef struct _jc_scm_Procedure$refs	_jc_scm_Procedure$refs;
typedef struct _jc_scm_Procedure$nonrefs	_jc_scm_Procedure$nonrefs;
typedef struct _jc_scm_Procedure$object	_jc_scm_Procedure$object;

typedef const struct _jc_scm_Procedure$vmethods	_jc_scm_Procedure$vmethods;
typedef const struct _jc_scm_Procedure$vtable	_jc_scm_Procedure$vtable;
typedef const struct _jc_scm_Procedure$vtype	_jc_scm_Procedure$vtype;

// Constructors
extern void _jc_scm_Procedure$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_Procedure$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_Procedure$method$apply$5e27fd10fb01c9e0(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_scm_Procedure$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_scm_Env$object *_jc_scm_Procedure$method$extendargs$da3942a08c440de1(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_Procedure$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_Procedure$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_Procedure$method_info$apply$5e27fd10fb01c9e0;
extern _jc_method _jc_scm_Procedure$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_Procedure$method_info$extendargs$da3942a08c440de1;
extern _jc_method _jc_scm_Procedure$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_Procedure$vmethods {
	struct _jc_object	*(*apply$5e27fd10fb01c9e0)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_scm_Env$object	*(*extendargs$da3942a08c440de1)(_jc_env *, struct _jc_scm_Procedure$object *, struct _jc_scm_Cell$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_Procedure$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_Procedure$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_Procedure$vmethods	scm_Procedure;
};

// Vtype
struct _jc_scm_Procedure$vtype {
	_jc_type			type;
	_jc_scm_Procedure$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_Procedure$sub_refs {
	struct _jc_scm_Cell$object	*body;
	struct _jc_scm_Cell$object	*formals;
	struct _jc_scm_Env$object	*procenv;
};

// Reference instance fields (object)
struct _jc_scm_Procedure$refs {
    _jc_scm_Procedure$sub_refs	scm_Procedure;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_Procedure$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_Procedure$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_Procedure$sub_nonrefs	scm_Procedure;
};

// Object instance structure
struct _jc_scm_Procedure$object {
	_jc_scm_Procedure$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_Procedure$vtype	*vtype;
	_jc_scm_Procedure$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_Procedure$vtype _jc_scm_Procedure$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_Procedure, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_Procedure$class_object;

#endif	/* _JC_scm_Procedure_H_ */
